@@ -1,9 +1,9 @@
 """
-IMGO - Compile, process, and augment image data.
--------------------------------------------------
+IMGO - Process, augment, and balance image data.
+------------------------------------------------
 AUGTOOLS module: 
 
-Last updated: version 2.3.0
+Last updated: version 2.3.2
 
 Classes
 -------        
@@ -1075,7 +1075,7 @@ class Augmenter:
 
         if source_type == "path":
 
-            from imgo_test.uptools import img_to_df
+            from imgo.uptools import img_to_df
 
             df = img_to_df(source)
             sample = df.sample()
@@ -1199,8 +1199,8 @@ class Augmenter:
             (if save is False).
         """
 
-        from imgo_test.uptools import img_to_df
-        from imgo_test.uptools import read_img_df
+        from imgo.uptools import img_to_df
+        from imgo.uptools import read_img_df
 
         all_class_arrays = []
         all_aug_indices = []
